==> checker-3.25.0.jar: annotated-jdk/src/jdk.javadoc/share/classes/jdk/javadoc/internal/tool/Main.java <==
/*
 * Copyright (c) 2000, 2016, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package jdk.javadoc.internal.tool;

import org.checkerframework.dataflow.qual.Pure;
import java.io.PrintWriter;

public class Main {

    public static void main(String... args);

    public static int execute(String... args);

    public static int execute(String[] args, PrintWriter writer);

    public static int execute(String[] args, PrintWriter outWriter, PrintWriter errWriter);

    public static enum Result {

        OK(0), ERROR(1), CMDERR(2), SYSERR(3), ABNORMAL(4);

        @Pure
        public boolean isOK();

        public final int exitCode;

        @Override
        public String toString();
    }
}

==> checker-3.48.2.jar: annotated-jdk/src/jdk.javadoc/share/classes/jdk/javadoc/internal/tool/Main.java <==
/*
 * Copyright (c) 2000, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package jdk.javadoc.internal.tool;

import org.checkerframework.dataflow.qual.Pure;
import java.io.PrintWriter;

public class Main {

    public static void main(String... args);

    public static int execute(String... args);

    public static int execute(String[] args, PrintWriter writer);

    public static int execute(String[] args, PrintWriter outWriter, PrintWriter errWriter);

    public enum Result {

        OK(0), ERROR(1), CMDERR(2), SYSERR(3), ABNORMAL(4);

        @Pure
        public boolean isOK();

        public final int exitCode;

        @Override
        public String toString();
    }
}
